@@ -27,11 +27,11 @@ extern Tk_EventProc *xctk_drag(ClientData, XEvent *);
 extern Tk_EventProc *xctk_draglscroll(ClientData, XEvent *);
 extern Tk_EventProc *xctk_dragfilebox(ClientData, XEvent *);
 extern int XcTagCallback(Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
-extern Tcl_Obj *evaluate_raw(oparamptr);
+extern Tcl_Obj *evaluate_raw(oparamptr, int *);
 extern char *TCL_to_PS(char *);
 #endif
 
-extern char *evaluate_expr(oparamptr);
+extern char *evaluate_expr(oparamptr, objinstptr);
 
 /* from elements.c: */
 
@@ -581,7 +581,7 @@ extern void writeflat(objectptr, CalllistPtr, char *, FILE *, char *);
 extern void writeglobals(objectptr, FILE *);
 extern void writehierarchy(objectptr, CalllistPtr, FILE *);
 extern void writenet(objectptr, char *, char *);
-extern void writepcb(struct Ptab **, objectptr, CalllistPtr, char *, char *);
+extern Boolean writepcb(struct Ptab **, objectptr, CalllistPtr, char *, char *);
 extern void outputpcb(struct Ptab *, FILE *);
 extern void freepcb(struct Ptab *);
 extern void freegenlist(Genericlist *);
@@ -745,7 +745,7 @@ extern stringpart *nextstringpart(stringpart *, objinstptr);
 extern stringpart *makesegment(stringpart **, stringpart *);
 extern stringpart *splitstring(int, stringpart **, objinstptr);
 extern stringpart *mergestring(stringpart *);
-extern stringpart *linkstring(objinstptr, stringpart *);
+extern stringpart *linkstring(objinstptr, stringpart *, Boolean);
 extern int findcurfont(int, stringpart *, objinstptr);
 extern stringpart *findstringpart(int, int *, stringpart *, objinstptr);
 extern void charprint(char *, stringpart *, int);
