@@ -29,7 +29,8 @@ typedef unsigned long	u_long;
 
 #ifdef TCL_WRAPPER
   #define malloc Tcl_Alloc
-  #define calloc(a,b) Tcl_Alloc(a * b)
+  /* (see definition of my_calloc in the asg subdirectory) */
+  // #define calloc(a,b) Tcl_Alloc(a * b)
   #define free(a) Tcl_Free((char *)(a))
   #define realloc(a,b) Tcl_Realloc((char *)(a), b)
   #undef strdup
@@ -100,7 +101,9 @@ ERROR: Cannot compile without knowing the size of a pointer.  See xcircuit.h.
 #define PLIST_INCR(a) \
 	(a)->plist = (genericptr *) realloc ((a)->plist, \
 	((a)->parts + 1) * sizeof(genericptr))
-#define SELECTTYPE(a)   ((*(topobject->plist + *(a)))->type & ALL_TYPES)
+#define SELECTTYPE(a)   ((areastruct.drawstack != NULL) ? \
+			OBJINST : \
+			((*(topobject->plist + *(a)))->type & ALL_TYPES))
 #define SELTOCOLOR(a)	(*(topobject->plist + *(a)))->color
 #define GSELTOCOLOR(b, a) (*((b)->plist + *(a)))->color
 #define ENDPART		topobject->plist + topobject->parts
@@ -131,11 +134,15 @@ ERROR: Cannot compile without knowing the size of a pointer.  See xcircuit.h.
 
 #define SELTOPOLY(a)	TOPOLY(topobject->plist + (*(a)))
 #define SELTOLABEL(a)	TOLABEL(topobject->plist + (*(a)))
-#define SELTOOBJINST(a)	TOOBJINST(topobject->plist + (*(a)))
+#define SELTOOBJINST(a)	((areastruct.drawstack != NULL) ? \
+			areastruct.drawstack->thisinst : \
+			TOOBJINST(topobject->plist + (*(a))))
 #define SELTOARC(a)	TOARC(topobject->plist + (*(a)))
 #define SELTOSPLINE(a)	TOSPLINE(topobject->plist + (*(a)))
 #define SELTOPATH(a)	TOPATH(topobject->plist + (*(a)))
-#define SELTOGENERIC(a) (*(topobject->plist + (*(a))))
+#define SELTOGENERIC(a) ((areastruct.drawstack != NULL) ? \
+			(genericptr)areastruct.drawstack->thisinst : \
+			(*(topobject->plist + (*(a)))))
 
 /* creation of new elements */
 
@@ -310,8 +317,8 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define FONT_SCALE	14  /* font scale change; data = scale		*/
 #define FONT_COLOR	15  /* font color change; data = color		*/
 #define KERN		16  /* set new kern values; data = kern x, y	*/
-#define PARAM_START	17  /* bounds a parameter; data = param #	*/
-#define PARAM_END	18  /* bounds a parameter; data = param #	*/
+#define PARAM_START	17  /* bounds a parameter; data = param key	*/
+#define PARAM_END	18  /* bounds a parameter; no data 		*/
 
 #define SPECIAL		63  /* used only when called from menu		*/
 #define NULL_TYPE	255 /* used as a placeholder			*/
@@ -1166,6 +1173,7 @@ typedef struct {
    objectptr	editstack;
    Matrixptr	MatStack;
    pushlistptr	stack;
+   pushlistptr	drawstack;
    short	editcycle;
    short	editpart, editsubpart;
    char		*lastbackground;
